# musodium
Pythonic Music Player.

# Why not just use lavalink?
Well musodium is mean't to be a direct ancestor to lavalink.
but faster and more productive. we also plan to use the full power
of yt-dlp to support as much websites as possible.